Discover Packages
github.com/jacobcxdev/cq
internal
provider
package
Version:
v0.5.0
Opens a new window with list of versions in this module.
Published: Mar 30, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Account struct {
AccountID string `json:"id"`
Email string `json:"email,omitempty"`
Label string `json:"label,omitempty"`
RateLimitTier string `json:"rate_limit_tier,omitempty"`
Active bool `json:"active"`
SwitchID string `json:"switch_id,omitempty"`
}
ID identifies a provider.
const (
Claude ID = "claude"
Codex ID = "codex"
Gemini ID = "gemini"
)
Provider fetches quota information for an AI service.
Services groups the service implementations for a provider.
Currently only Usage is populated; additional fields can be added
without changing the Runner interface.
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.